nms_extra_float

Function nms_extra_float 

pub fn nms_extra_float<E: Send + Sync>(
    iou: f32,
    boxes: Vec<(DetectBox, E)>,
) -> Vec<(DetectBox, E)>
Uses NMS to filter boxes based on the score and iou. Sorts boxes by score, then greedily selects a subset of boxes in descending order of score.

This is same as nms_float but will also include extra information along with each box, such as the index