postprocess_boxes_float

Function postprocess_boxes_float 

pub fn postprocess_boxes_float<B: BBoxTypeTrait, BOX: Float + AsPrimitive<f32> + Send + Sync, SCORE: Float + AsPrimitive<f32> + Send + Sync>(
    threshold: SCORE,
    boxes: ArrayView2<'_, BOX>,
    scores: ArrayView2<'_, SCORE>,
) -> Vec<DetectBox>
Post processes boxes and scores tensors into detection boxes, filtering out any boxes below the score threshold. The boxes tensor is converted to XYXY using the given BBoxTypeTrait. The order of the boxes is preserved.