Module float

Module float 

Functions

box_area
Area of a box, clamped to >= 0 per side. Mirrors ModelPack _areas.
intersection_area
Area of the axis-aligned intersection of two boxes, clamped to >= 0 per side. Mirrors the inter term in ModelPack metrics/tiled.py::_match.
ios_value
Intersection-over-Smaller value in [0, 1]. Mirrors ModelPack _match(metric='ios'): inter / max(min(area_a, area_b), 1e-9). Used by the tiled-detection merge: a seam-split object has low IoU but high IoS.
iou_value
Intersection-over-Union value in [0, 1]. Mirrors ModelPack _match(metric='iou'): inter / max(area_a + area_b - inter, 1e-9).
jaccard
Returns true if the IOU of the given bounding boxes is greater than the iou threshold
jaccard_batch4
Batch IoU check: test one reference box a against 4 candidate boxes.
nms_class_aware_float
Class-aware NMS: only suppress boxes with the same label.
nms_extra_class_aware_float
Class-aware NMS with extra data: only suppress boxes with the same label.
nms_extra_float
Uses NMS to filter boxes based on the score and iou. Sorts boxes by score, then greedily selects a subset of boxes in descending order of score.
nms_float
Uses NMS to filter boxes based on the score and iou. Sorts boxes by score, then greedily selects a subset of boxes in descending order of score.
postprocess_boxes_float
Post processes boxes and scores tensors into detection boxes, filtering out any boxes below the score threshold. The boxes tensor is converted to XYXY using the given BBoxTypeTrait. The order of the boxes is preserved.
postprocess_boxes_index_float
Post processes boxes and scores tensors into detection boxes, filtering out any boxes below the score threshold. The boxes tensor is converted to XYXY using the given BBoxTypeTrait. The order of the boxes is preserved.
postprocess_boxes_multilabel_index_float
Multi-label variant of postprocess_boxes_index_float.