Intersection-over-Smaller value in [0, 1]. Mirrors ModelPack
_match(metric='ios'): inter / max(min(area_a, area_b), 1e-9). Used by the
tiled-detection merge: a seam-split object has low IoU but high IoS.
Post processes boxes and scores tensors into detection boxes, filtering out
any boxes below the score threshold. The boxes tensor is converted to XYXY
using the given BBoxTypeTrait. The order of the boxes is preserved.
Post processes boxes and scores tensors into detection boxes, filtering out
any boxes below the score threshold. The boxes tensor is converted to XYXY
using the given BBoxTypeTrait. The order of the boxes is preserved.