Module float

Module float 

Functions

jaccard
Returns true if the IOU of the given bounding boxes is greater than the iou threshold
nms_class_aware_float
Class-aware NMS: only suppress boxes with the same label.
nms_extra_class_aware_float
Class-aware NMS with extra data: only suppress boxes with the same label.
nms_extra_float
Uses NMS to filter boxes based on the score and iou. Sorts boxes by score, then greedily selects a subset of boxes in descending order of score.
nms_float
Uses NMS to filter boxes based on the score and iou. Sorts boxes by score, then greedily selects a subset of boxes in descending order of score.
postprocess_boxes_float
Post processes boxes and scores tensors into detection boxes, filtering out any boxes below the score threshold. The boxes tensor is converted to XYXY using the given BBoxTypeTrait. The order of the boxes is preserved.
postprocess_boxes_index_float
Post processes boxes and scores tensors into detection boxes, filtering out any boxes below the score threshold. The boxes tensor is converted to XYXY using the given BBoxTypeTrait. The order of the boxes is preserved.