pub struct DetectBox {
pub bbox: BoundingBox,
pub score: f32,
pub label: usize,
}Expand description
A detection box with f32 bbox and score
Fields
bbox: BoundingBoxscore: f32model-specific score for this detection, higher implies more confidence
label: usizelabel index for this detection
Implementations
Sourceimpl DetectBox
impl DetectBox
Sourcepub fn equal_within_delta(&self, rhs: &DetectBox, eps: f32) -> bool
pub fn equal_within_delta(&self, rhs: &DetectBox, eps: f32) -> bool
Returns true if one detect box is equal to another detect box, within
the given eps
Examples
let box1 = DetectBox {
bbox: edgefirst_decoder::BoundingBox {
xmin: 0.1,
ymin: 0.2,
xmax: 0.3,
ymax: 0.4,
},
score: 0.5,
label: 1,
};
let box2 = DetectBox {
bbox: edgefirst_decoder::BoundingBox {
xmin: 0.101,
ymin: 0.199,
xmax: 0.301,
ymax: 0.399,
},
score: 0.510,
label: 1,
};
assert!(box1.equal_within_delta(&box2, 0.011));Trait Implementations
impl Copy for DetectBox
impl StructuralPartialEq for DetectBox