pub struct Segmentation {
pub xmin: f32,
pub ymin: f32,
pub xmax: f32,
pub ymax: f32,
pub segmentation: Array3<u8>,
}Expand description
A segmentation result with a segmentation mask, and a normalized bounding box representing the area that the segmentation mask covers
Fields
xmin: f32left-most normalized coordinate of the segmentation box
ymin: f32top-most normalized coordinate of the segmentation box
xmax: f32right-most normalized coordinate of the segmentation box
ymax: f32bottom-most normalized coordinate of the segmentation box
segmentation: Array3<u8>3D segmentation array of shape (H, W, C).
For instance segmentation (e.g. YOLO): C=1 — binary per-instance
mask where values >= 128 indicate object presence.
For semantic segmentation (e.g. ModelPack): C=num_classes — per-pixel
class scores where the object class is the argmax index.