Skip to main content Module yolo Copy item path Source decode_yolo_det Decodes YOLO detection outputs from quantized tensors into detection boxes. decode_yolo_det_float Decodes YOLO detection outputs from float tensors into detection boxes. decode_yolo_end_to_end_det_float Decodes end-to-end YOLO detection outputs (post-NMS from model).
Expects an array of shape (6, N), where the first dimension (rows)
corresponds to the 6 per-detection features
[x1, y1, x2, y2, conf, class] and the second dimension (columns)
indexes the N detections.
Boxes are output directly without NMS (the model already applied NMS). decode_yolo_end_to_end_segdet_float Decodes end-to-end YOLO detection + segmentation outputs (post-NMS from
model). decode_yolo_segdet_float Decodes YOLO detection and segmentation outputs from float tensors into
detection boxes and segmentation masks. decode_yolo_segdet_quant Decodes YOLO detection and segmentation outputs from quantized tensors into
detection boxes and segmentation masks. decode_yolo_split_det_float Decodes YOLO split detection outputs from float tensors into detection
boxes. decode_yolo_split_det_quant Decodes YOLO split detection outputs from quantized tensors into detection
boxes. decode_yolo_split_segdet Decodes YOLO split detection segmentation outputs from quantized tensors
into detection boxes and segmentation masks. decode_yolo_split_segdet_float Decodes YOLO split detection segmentation outputs from float tensors
into detection boxes and segmentation masks. impl_yolo_float Internal implementation of YOLO decoding for float tensors. impl_yolo_quant Internal implementation of YOLO decoding for quantized tensors. impl_yolo_segdet_float Internal implementation of YOLO detection segmentation decoding for
float tensors. impl_yolo_segdet_quant Internal implementation of YOLO detection segmentation decoding for
quantized tensors. impl_yolo_split_float Internal implementation of YOLO split detection decoding for float tensors. impl_yolo_split_quant Internal implementation of YOLO split detection decoding for quantized
tensors. impl_yolo_split_segdet_float Internal implementation of YOLO split detection segmentation decoding for
float tensors. impl_yolo_split_segdet_quant Internal implementation of YOLO split detection segmentation decoding for
quantized tensors. yolo_segmentation_to_mask Converts Yolo Instance Segmentation into a 2D mask.